@@ -3,7 +3,7 @@
 
 int main(int argc, char *argv[])
 {
-    QApplication a(argc, argv);
+    QApplication app(argc, argv);
 
     Q_INIT_RESOURCE(quickflickr);
     
@@ -13,8 +13,9 @@ int main(int argc, char *argv[])
 #ifdef Q_WS_MAC
         loader.show();
 #else
+        app.setGraphicsSystem("raster");
         loader.showFullScreen();
 #endif
     
-    return a.exec();
+    return app.exec();
 }
